import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';
import ReactDOM from 'react-dom';
import {
  max,
  min,
  scaleBand,
  scaleLinear,
  extent,
  scaleTime,
  timeFormat,
  histogram as bin,
  timeMonths,
  sum
} from 'd3';

const width = 960;
const height = 500;

const margin = {
  top: 20,
  bottom: 70,
  left: 120,
  right: 20,
};

const xAxisLabelOffset = 60;
const yAxisLabelOffset = 50;

const xAxisTickFormat = (tickValue) => timeFormat('%m/%d/%Y')(tickValue)

const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const xValue = (d) => d['Reported Date'];
  const xAxisLabel = 'Reported Date';
  const yValue = (d) => d['Total Dead and Missing'];
  const yAxisLabel = 'Total Dead and Missing';

   
  

  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  const [start, end] = xScale.domain();
  
  const dat = bin()
  	.value(xValue)
  	.domain(xScale.domain())
  	.thresholds(timeMonths(start, end))(data)
  	.map( array => ({
    	y: sum(array, yValue),
      x0: array.x0,
      x1: array.x1,
    }))  	

  const yScale = scaleLinear()
    .domain([0, max(dat, d => d.y)])
    .range([innerHeight, 0]);
  
 
  
  
  
  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        <Marks
          dat={dat}
          xScale={xScale}
          yScale={yScale}
          innerHeight = {innerHeight}
          circleRadius={2.5}
          xAxisTickFormat={xAxisTickFormat}
        />
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          xAxisTickFormat={xAxisTickFormat}
          tickOffset={10}
        />
        <AxisLeft
          yScale={yScale}
          innerWidth={innerWidth}
          tickOffset={5}
        />
        <text
          className="axis-label"
          x={innerWidth / 2}
          y={innerHeight + xAxisLabelOffset}
          textAnchor="middle"
        >
          {xAxisLabel}
        </text>
        <text
          className="axis-label"
          textAnchor="middle"
          transform={`translate(${-yAxisLabelOffset}, ${
            innerHeight / 2 + 20
          }) rotate(-90)`}
        >
          {yAxisLabel}
        </text>
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
